@@ -6,35 +6,37 @@ Some fields might require additional dependencies to be installed.
 """
 
 import re
-import six
 import string
 
 try:
     import uuid
+
     HAS_UUID = True
 except ImportError:
     HAS_UUID = False
 
 try:
     import shortuuid
+
     HAS_SHORT_UUID = True
 except ImportError:
     HAS_SHORT_UUID = False
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.db.models import DateTimeField, CharField, SlugField, Q
+from django.db.models import DateTimeField, CharField, SlugField, Q, UniqueConstraint
 from django.db.models.constants import LOOKUP_SEP
 from django.template.defaultfilters import slugify
 from django.utils.crypto import get_random_string
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
 
-MAX_UNIQUE_QUERY_ATTEMPTS = getattr(settings, 'EXTENSIONS_MAX_UNIQUE_QUERY_ATTEMPTS', 100)
+MAX_UNIQUE_QUERY_ATTEMPTS = getattr(
+    settings, "EXTENSIONS_MAX_UNIQUE_QUERY_ATTEMPTS", 100
+)
 
 
-class UniqueFieldMixin(object):
-
+class UniqueFieldMixin:
     def check_is_bool(self, attrname):
         if not isinstance(getattr(self, attrname), bool):
             raise ValueError("'{}' argument must be True or False".format(attrname))
@@ -42,7 +44,8 @@ class UniqueFieldMixin(object):
     @staticmethod
     def _get_fields(model_cls):
         return [
-            (f, f.model if f.model != model_cls else None) for f in model_cls._meta.get_fields()
+            (f, f.model if f.model != model_cls else None)
+            for f in model_cls._meta.get_fields()
             if not f.is_relation or f.one_to_one or (f.many_to_one and f.related_model)
         ]
 
@@ -68,21 +71,24 @@ class UniqueFieldMixin(object):
 
         # for support django 2.2+
         query = Q()
-        constraints = getattr(model_instance._meta, 'constraints', None)
+        constraints = getattr(model_instance._meta, "constraints", None)
         if constraints:
-            for constraint in constraints:
-                if self.attname in constraint.fields:
+            unique_constraints = filter(
+                lambda c: isinstance(c, UniqueConstraint), constraints
+            )
+            for unique_constraint in unique_constraints:
+                if self.attname in unique_constraint.fields:
                     condition = {
                         field: getattr(model_instance, field, None)
-                        for field in constraint.fields
+                        for field in unique_constraint.fields
                         if field != self.attname
                     }
                     query &= Q(**condition)
 
-        new = six.next(iterator)
+        new = next(iterator)
         kwargs[self.attname] = new
         while not new or queryset.filter(query, **kwargs):
-            new = six.next(iterator)
+            new = next(iterator)
             kwargs[self.attname] = new
         setattr(model_instance, self.attname, new)
         return new
@@ -141,14 +147,14 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
             slug = AutoSlugField(populate_from='title')
 
     Inspired by SmileyChris' Unique Slugify snippet:
-    http://www.djangosnippets.org/snippets/690/
+    https://www.djangosnippets.org/snippets/690/
     """
 
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('blank', True)
-        kwargs.setdefault('editable', False)
+        kwargs.setdefault("blank", True)
+        kwargs.setdefault("editable", False)
 
-        populate_from = kwargs.pop('populate_from', None)
+        populate_from = kwargs.pop("populate_from", None)
         if populate_from is None:
             raise ValueError("missing 'populate_from' argument")
         else:
@@ -156,21 +162,26 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
 
         if not callable(populate_from):
             if not isinstance(populate_from, (list, tuple)):
-                populate_from = (populate_from, )
+                populate_from = (populate_from,)
 
-            if not all(isinstance(e, six.string_types) for e in populate_from):
-                raise TypeError("'populate_from' must be str or list[str] or tuple[str], found `%s`" % populate_from)
+            if not all(isinstance(e, str) for e in populate_from):
+                raise TypeError(
+                    "'populate_from' must be str or list[str] or tuple[str], found `%s`"
+                    % populate_from
+                )
 
-        self.slugify_function = kwargs.pop('slugify_function', slugify)
-        self.separator = kwargs.pop('separator', six.u('-'))
-        self.overwrite = kwargs.pop('overwrite', False)
-        self.check_is_bool('overwrite')
-        self.overwrite_on_add = kwargs.pop('overwrite_on_add', True)
-        self.check_is_bool('overwrite_on_add')
-        self.allow_duplicates = kwargs.pop('allow_duplicates', False)
-        self.check_is_bool('allow_duplicates')
-        self.max_unique_query_attempts = kwargs.pop('max_unique_query_attempts', MAX_UNIQUE_QUERY_ATTEMPTS)
-        super(AutoSlugField, self).__init__(*args, **kwargs)
+        self.slugify_function = kwargs.pop("slugify_function", slugify)
+        self.separator = kwargs.pop("separator", "-")
+        self.overwrite = kwargs.pop("overwrite", False)
+        self.check_is_bool("overwrite")
+        self.overwrite_on_add = kwargs.pop("overwrite_on_add", True)
+        self.check_is_bool("overwrite_on_add")
+        self.allow_duplicates = kwargs.pop("allow_duplicates", False)
+        self.check_is_bool("allow_duplicates")
+        self.max_unique_query_attempts = kwargs.pop(
+            "max_unique_query_attempts", MAX_UNIQUE_QUERY_ATTEMPTS
+        )
+        super().__init__(*args, **kwargs)
 
     def _slug_strip(self, value):
         """
@@ -180,28 +191,31 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         If an alternate separator is used, it will also replace any instances
         of the default '-' separator with the new separator.
         """
-        re_sep = '(?:-|%s)' % re.escape(self.separator)
-        value = re.sub('%s+' % re_sep, self.separator, value)
-        return re.sub(r'^%s+|%s+$' % (re_sep, re_sep), '', value)
+        re_sep = "(?:-|%s)" % re.escape(self.separator)
+        value = re.sub("%s+" % re_sep, self.separator, value)
+        return re.sub(r"^%s+|%s+$" % (re_sep, re_sep), "", value)
 
     @staticmethod
     def slugify_func(content, slugify_function):
         if content:
             return slugify_function(content)
-        return ''
+        return ""
 
     def slug_generator(self, original_slug, start):
         yield original_slug
         for i in range(start, self.max_unique_query_attempts):
             slug = original_slug
-            end = '%s%s' % (self.separator, i)
+            end = "%s%s" % (self.separator, i)
             end_len = len(end)
             if self.slug_len and len(slug) + end_len > self.slug_len:
-                slug = slug[:self.slug_len - end_len]
+                slug = slug[: self.slug_len - end_len]
                 slug = self._slug_strip(slug)
-            slug = '%s%s' % (slug, end)
+            slug = "%s%s" % (slug, end)
             yield slug
-        raise RuntimeError('max slug attempts for %s exceeded (%s)' % (original_slug, self.max_unique_query_attempts))
+        raise RuntimeError(
+            "max slug attempts for %s exceeded (%s)"
+            % (original_slug, self.max_unique_query_attempts)
+        )
 
     def create_slug(self, model_instance, add):
         slug = getattr(model_instance, self.attname)
@@ -220,15 +234,17 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         # get fields to populate from and slug field to set
         populate_from = self._populate_from
         if not isinstance(populate_from, (list, tuple)):
-            populate_from = (populate_from, )
+            populate_from = (populate_from,)
 
         slug_field = model_instance._meta.get_field(self.attname)
-        slugify_function = getattr(model_instance, 'slugify_function', self.slugify_function)
+        slugify_function = getattr(
+            model_instance, "slugify_function", self.slugify_function
+        )
 
         # slugify the original field content and set next step to 2
         slug_for_field = lambda lookup_value: self.slugify_func(
             self.get_slug_fields(model_instance, lookup_value),
-            slugify_function=slugify_function
+            slugify_function=slugify_function,
         )
         slug = self.separator.join(map(slug_for_field, populate_from))
         start = 2
@@ -237,7 +253,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         # and clean-up
         self.slug_len = slug_field.max_length
         if self.slug_len:
-            slug = slug[:self.slug_len]
+            slug = slug[: self.slug_len]
         slug = self._slug_strip(slug)
         original_slug = slug
 
@@ -246,7 +262,8 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
             return slug
 
         return self.find_unique(
-            model_instance, slug_field, self.slug_generator(original_slug, start))
+            model_instance, slug_field, self.slug_generator(original_slug, start)
+        )
 
     def get_slug_fields(self, model_instance, lookup_value):
         if callable(lookup_value):
@@ -260,30 +277,31 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
                 attr = getattr(attr, elem)
             except AttributeError:
                 raise AttributeError(
-                    "value {} in AutoSlugField's 'populate_from' argument {} returned an error - {} has no attribute {}".format(
-                        elem, lookup_value, attr, elem))
-
+                    "value {} in AutoSlugField's 'populate_from' argument {} returned an error - {} has no attribute {}".format(  # noqa: E501
+                        elem, lookup_value, attr, elem
+                    )
+                )
         if callable(attr):
             return "%s" % attr()
 
         return attr
 
     def pre_save(self, model_instance, add):
-        value = force_text(self.create_slug(model_instance, add))
+        value = force_str(self.create_slug(model_instance, add))
         return value
 
     def get_internal_type(self):
         return "SlugField"
 
     def deconstruct(self):
-        name, path, args, kwargs = super(AutoSlugField, self).deconstruct()
-        kwargs['populate_from'] = self._populate_from
-        if not self.separator == six.u('-'):
-            kwargs['separator'] = self.separator
+        name, path, args, kwargs = super().deconstruct()
+        kwargs["populate_from"] = self._populate_from
+        if not self.separator == "-":
+            kwargs["separator"] = self.separator
         if self.overwrite is not False:
-            kwargs['overwrite'] = True
+            kwargs["overwrite"] = True
         if self.allow_duplicates is not False:
-            kwargs['allow_duplicates'] = True
+            kwargs["allow_duplicates"] = True
         return name, path, args, kwargs
 
 
@@ -317,41 +335,52 @@ class RandomCharField(UniqueFieldMixin, CharField):
 
     include_punctuation
         If set to True, include punctuation characters (default: False)
+
+    keep_default
+        If set to True, keeps the default initialization value (default: False)
     """
 
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('blank', True)
-        kwargs.setdefault('editable', False)
+        kwargs.setdefault("blank", True)
+        kwargs.setdefault("editable", False)
 
-        self.length = kwargs.pop('length', None)
+        self.length = kwargs.pop("length", None)
         if self.length is None:
             raise ValueError("missing 'length' argument")
-        kwargs['max_length'] = self.length
+        kwargs["max_length"] = self.length
 
-        self.lowercase = kwargs.pop('lowercase', False)
-        self.check_is_bool('lowercase')
-        self.uppercase = kwargs.pop('uppercase', False)
-        self.check_is_bool('uppercase')
+        self.lowercase = kwargs.pop("lowercase", False)
+        self.check_is_bool("lowercase")
+        self.uppercase = kwargs.pop("uppercase", False)
+        self.check_is_bool("uppercase")
         if self.uppercase and self.lowercase:
-            raise ValueError("the 'lowercase' and 'uppercase' arguments are mutually exclusive")
-        self.include_digits = kwargs.pop('include_digits', True)
-        self.check_is_bool('include_digits')
-        self.include_alpha = kwargs.pop('include_alpha', True)
-        self.check_is_bool('include_alpha')
-        self.include_punctuation = kwargs.pop('include_punctuation', False)
-        self.check_is_bool('include_punctuation')
-        self.max_unique_query_attempts = kwargs.pop('max_unique_query_attempts', MAX_UNIQUE_QUERY_ATTEMPTS)
+            raise ValueError(
+                "the 'lowercase' and 'uppercase' arguments are mutually exclusive"
+            )
+        self.include_digits = kwargs.pop("include_digits", True)
+        self.check_is_bool("include_digits")
+        self.include_alpha = kwargs.pop("include_alpha", True)
+        self.check_is_bool("include_alpha")
+        self.include_punctuation = kwargs.pop("include_punctuation", False)
+        self.keep_default = kwargs.pop("keep_default", False)
+        self.check_is_bool("include_punctuation")
+        self.max_unique_query_attempts = kwargs.pop(
+            "max_unique_query_attempts", MAX_UNIQUE_QUERY_ATTEMPTS
+        )
 
         # Set unique=False unless it's been set manually.
-        if 'unique' not in kwargs:
-            kwargs['unique'] = False
+        if "unique" not in kwargs:
+            kwargs["unique"] = False
 
-        super(RandomCharField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def random_char_generator(self, chars):
         for i in range(self.max_unique_query_attempts):
-            yield ''.join(get_random_string(self.length, chars))
-        raise RuntimeError('max random character attempts exceeded (%s)' % self.max_unique_query_attempts)
+            yield "".join(get_random_string(self.length, chars))
+        raise RuntimeError(
+            "max random character attempts exceeded (%s)"
+            % self.max_unique_query_attempts
+        )
 
     def in_unique_together(self, model_instance):
         for params in model_instance._meta.unique_together:
@@ -360,10 +389,12 @@ class RandomCharField(UniqueFieldMixin, CharField):
         return False
 
     def pre_save(self, model_instance, add):
-        if not add and getattr(model_instance, self.attname) != '':
+        if (not add or self.keep_default) and getattr(
+            model_instance, self.attname
+        ) != "":
             return getattr(model_instance, self.attname)
 
-        population = ''
+        population = ""
         if self.include_alpha:
             if self.lowercase:
                 population += string.ascii_lowercase
@@ -380,7 +411,7 @@ class RandomCharField(UniqueFieldMixin, CharField):
 
         random_chars = self.random_char_generator(population)
         if not self.unique and not self.in_unique_together(model_instance):
-            new = six.next(random_chars)
+            new = next(random_chars)
             setattr(model_instance, self.attname, new)
             return new
 
@@ -394,21 +425,21 @@ class RandomCharField(UniqueFieldMixin, CharField):
         return "CharField"
 
     def deconstruct(self):
-        name, path, args, kwargs = super(RandomCharField, self).deconstruct()
-        kwargs['length'] = self.length
-        del kwargs['max_length']
+        name, path, args, kwargs = super().deconstruct()
+        kwargs["length"] = self.length
+        del kwargs["max_length"]
         if self.lowercase is True:
-            kwargs['lowercase'] = self.lowercase
+            kwargs["lowercase"] = self.lowercase
         if self.uppercase is True:
-            kwargs['uppercase'] = self.uppercase
+            kwargs["uppercase"] = self.uppercase
         if self.include_alpha is False:
-            kwargs['include_alpha'] = self.include_alpha
+            kwargs["include_alpha"] = self.include_alpha
         if self.include_digits is False:
-            kwargs['include_digits'] = self.include_digits
+            kwargs["include_digits"] = self.include_digits
         if self.include_punctuation is True:
-            kwargs['include_punctuation'] = self.include_punctuation
+            kwargs["include_punctuation"] = self.include_punctuation
         if self.unique is True:
-            kwargs['unique'] = self.unique
+            kwargs["unique"] = self.unique
         return name, path, args, kwargs
 
 
@@ -420,22 +451,22 @@ class CreationDateTimeField(DateTimeField):
     """
 
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('editable', False)
-        kwargs.setdefault('blank', True)
-        kwargs.setdefault('auto_now_add', True)
+        kwargs.setdefault("editable", False)
+        kwargs.setdefault("blank", True)
+        kwargs.setdefault("auto_now_add", True)
         DateTimeField.__init__(self, *args, **kwargs)
 
     def get_internal_type(self):
         return "DateTimeField"
 
     def deconstruct(self):
-        name, path, args, kwargs = super(CreationDateTimeField, self).deconstruct()
+        name, path, args, kwargs = super().deconstruct()
         if self.editable is not False:
-            kwargs['editable'] = True
+            kwargs["editable"] = True
         if self.blank is not True:
-            kwargs['blank'] = False
+            kwargs["blank"] = False
         if self.auto_now_add is not False:
-            kwargs['auto_now_add'] = True
+            kwargs["auto_now_add"] = True
         return name, path, args, kwargs
 
 
@@ -449,53 +480,65 @@ class ModificationDateTimeField(CreationDateTimeField):
     """
 
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('auto_now', True)
+        kwargs.setdefault("auto_now", True)
         DateTimeField.__init__(self, *args, **kwargs)
 
     def get_internal_type(self):
         return "DateTimeField"
 
     def deconstruct(self):
-        name, path, args, kwargs = super(ModificationDateTimeField, self).deconstruct()
+        name, path, args, kwargs = super().deconstruct()
         if self.auto_now is not False:
-            kwargs['auto_now'] = True
+            kwargs["auto_now"] = True
         return name, path, args, kwargs
 
     def pre_save(self, model_instance, add):
-        if not getattr(model_instance, 'update_modified', True):
+        if not getattr(model_instance, "update_modified", True):
             return getattr(model_instance, self.attname)
-        return super(ModificationDateTimeField, self).pre_save(model_instance, add)
+        return super().pre_save(model_instance, add)
 
 
 class UUIDVersionError(Exception):
     pass
 
 
-class UUIDFieldMixin(object):
+class UUIDFieldMixin:
     """
     UUIDFieldMixin
 
     By default uses UUID version 4 (randomly generated UUID).
 
     The field support all uuid versions which are natively supported by the uuid python module, except version 2.
-    For more information see: http://docs.python.org/lib/module-uuid.html
-    """
+    For more information see: https://docs.python.org/lib/module-uuid.html
+    """  # noqa: E501
 
     DEFAULT_MAX_LENGTH = 36
 
     def __init__(
-            self, verbose_name=None, name=None, auto=True, version=4,
-            node=None, clock_seq=None, namespace=None, uuid_name=None, *args,
-            **kwargs):
+        self,
+        verbose_name=None,
+        name=None,
+        auto=True,
+        version=4,
+        node=None,
+        clock_seq=None,
+        namespace=None,
+        uuid_name=None,
+        *args,
+        **kwargs,
+    ):
         if not HAS_UUID:
-            raise ImproperlyConfigured("'uuid' module is required for UUIDField. (Do you have Python 2.5 or higher installed ?)")
+            raise ImproperlyConfigured(
+                "'uuid' module is required for UUIDField. "
+                "(Do you have Python 2.5 or higher installed ?)"
+            )
 
-        kwargs.setdefault('max_length', self.DEFAULT_MAX_LENGTH)
+        kwargs.setdefault("max_length", self.DEFAULT_MAX_LENGTH)
 
         if auto:
             self.empty_strings_allowed = False
-            kwargs['blank'] = True
-            kwargs.setdefault('editable', False)
+            kwargs["blank"] = True
+            kwargs.setdefault("editable", False)
 
         self.auto = auto
         self.version = version
@@ -504,8 +547,7 @@ class UUIDFieldMixin(object):
         self.namespace = namespace
         self.uuid_name = uuid_name or name
 
-        super(UUIDFieldMixin, self).__init__(
-            verbose_name=verbose_name, *args, **kwargs)
+        super().__init__(verbose_name=verbose_name, *args, **kwargs)
 
     def create_uuid(self):
         if not self.version or self.version == 4:
@@ -522,41 +564,41 @@ class UUIDFieldMixin(object):
             raise UUIDVersionError("UUID version %s is not valid." % self.version)
 
     def pre_save(self, model_instance, add):
-        value = super(UUIDFieldMixin, self).pre_save(model_instance, add)
+        value = super().pre_save(model_instance, add)
 
         if self.auto and add and value is None:
-            value = force_text(self.create_uuid())
+            value = force_str(self.create_uuid())
             setattr(model_instance, self.attname, value)
             return value
         else:
             if self.auto and not value:
-                value = force_text(self.create_uuid())
+                value = force_str(self.create_uuid())
                 setattr(model_instance, self.attname, value)
 
         return value
 
-    def formfield(self, **kwargs):
+    def formfield(self, form_class=None, choices_form_class=None, **kwargs):
         if self.auto:
             return None
-        return super(UUIDFieldMixin, self).formfield(**kwargs)
+        return super().formfield(form_class, choices_form_class, **kwargs)
 
     def deconstruct(self):
-        name, path, args, kwargs = super(UUIDFieldMixin, self).deconstruct()
+        name, path, args, kwargs = super().deconstruct()
 
-        if kwargs.get('max_length', None) == self.DEFAULT_MAX_LENGTH:
-            del kwargs['max_length']
+        if kwargs.get("max_length", None) == self.DEFAULT_MAX_LENGTH:
+            del kwargs["max_length"]
         if self.auto is not True:
-            kwargs['auto'] = self.auto
+            kwargs["auto"] = self.auto
         if self.version != 4:
-            kwargs['version'] = self.version
+            kwargs["version"] = self.version
         if self.node is not None:
-            kwargs['node'] = self.node
+            kwargs["node"] = self.node
         if self.clock_seq is not None:
-            kwargs['clock_seq'] = self.clock_seq
+            kwargs["clock_seq"] = self.clock_seq
         if self.namespace is not None:
-            kwargs['namespace'] = self.namespace
+            kwargs["namespace"] = self.namespace
         if self.uuid_name is not None:
-            kwargs['uuid_name'] = self.name
+            kwargs["uuid_name"] = self.name
 
         return name, path, args, kwargs
 
@@ -573,10 +615,13 @@ class ShortUUIDField(UUIDFieldMixin, CharField):
     DEFAULT_MAX_LENGTH = 22
 
     def __init__(self, *args, **kwargs):
-        super(ShortUUIDField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if not HAS_SHORT_UUID:
-            raise ImproperlyConfigured("'shortuuid' module is required for ShortUUIDField. (Do you have Python 2.5 or higher installed ?)")
-        kwargs.setdefault('max_length', self.DEFAULT_MAX_LENGTH)
+            raise ImproperlyConfigured(
+                "'shortuuid' module is required for ShortUUIDField. "
+                "(Do you have Python 2.5 or higher installed ?)"
+            )
+        kwargs.setdefault("max_length", self.DEFAULT_MAX_LENGTH)
 
     def create_uuid(self):
         if not self.version or self.version == 4:
