@@ -4,7 +4,7 @@ def load_ipython_extension(ipython):
     from django_extensions.management.shells import import_objects
 
     imported_objects = import_objects(
-        options={'dont_load': []},
+        options={"dont_load": []},
         style=no_style(),
     )
     ipython.push(imported_objects)
